@@ -229,7 +229,10 @@ static FILE_POINTER *DBH_locateT(DBHashTable *node,int keys)
 static DBHashTable *DBH_open_S(char *archivo,int mode)
 {
  DBHashTable *node; FILE *archin;
- if (strlen(archivo)>255) ABORT3
+ if (strlen(archivo)>255) {
+     ABORT3
+     return NULL;
+ }
  if (mode)
  {
   archin = fopen(archivo,"rb+");
@@ -247,8 +250,14 @@ static DBHashTable *DBH_open_S(char *archivo,int mode)
   fprintf(stdout,"\nFin de la base de datos (ftell()) = %ld", ftell(node->database));
   fprintf(stdout,"\ntamao de base de datos valida y vacia = %d", 1024);
   ABORT1
+  return NULL;
+ }
+ if (!DBH_readheader(node)){
+     fclose(archin);
+     free(node->head_info);
+     free(node);
+     return NULL;
  }
- DBH_readheader(node);
  node->operate=DBH_operate;
  node->branch    = (FILE_POINTER *)malloc(node->head_info->n_limit*sizeof(FILE_POINTER));
  node->newbranch = (FILE_POINTER *)malloc(node->head_info->n_limit*sizeof(FILE_POINTER));
@@ -395,6 +404,7 @@ static int DBH_readheader(DBHashTable *node)
 #endif
  return 1;
  error:
+#if 0
  {
   int i;
   unsigned char *byte;
@@ -422,9 +432,10 @@ static int DBH_readheader(DBHashTable *node)
 	if ((byte[i]>32)&&(byte[i]<126))	fprintf(stderr,"%c",byte[i]);
 	else  fprintf(stderr,"<%d>",byte[i]);
   }
-  ABORT1
  }
- return 1;
+#endif
+ ABORT1
+ return 0;
 }  /************************************************************************************/
 
 #ifdef TURN
